unit u_sysutils;

interface

uses
  Windows;

  function AllocMem(Size: Cardinal): Pointer;
  function CanUpdate(const DelayValue: Cardinal; const Force: Boolean): Boolean;
  function ExtractFileName(const FileName: string): string;
  function ExtractFilePath(const FilePath: string): string;
  function InttoStr(Value: Integer): string;
  function LowerCase(const S: string): string;
  function StrtoInt(const S: string): Integer;
  function StrToIntDef(const S: string; Default: Integer): Integer;
  function Trim(const S: string): string;
  function ValidFile(var F: file; FileName: string): Boolean;
  function ValidTextFile(var F: TextFile; FileName: string): Boolean;

implementation

function AllocMem(Size: Cardinal): Pointer;
begin
  GetMem(Result, Size);
  FillChar(Result^, Size, 0);
end;

var
  LastUpdate: Cardinal = 0;
  
function CanUpdate(const DelayValue: Cardinal; const Force: Boolean): Boolean;
begin
  Result := Force or ((GetTickCount - LastUpdate) >= DelayValue);
  if Result then LastUpdate := GetTickCount;
end;

function ExtractFileName(const FileName: string): string;
var
  i, Len: Integer;
  Ch: Char;
begin
  Len := Length(FileName);
  for i := Len downto 1 do
  begin
    Ch := FileName[i];
    if (Ch = '\') or (Ch = '/') then
    begin
      Result := Copy(FileName, i + 1, Len - i);
      Break;
    end;
  end;
end;

function ExtractFilePath(const FilePath: string): string;
var
  i, Len: Integer;
  Ch: Char;
begin
  Len := Length(FilePath);
  for i := Len downto 1 do
  begin
    Ch := FilePath[i];
    if (Ch = '\') or (Ch = '/') then
    begin
      Result := Copy(FilePath, 1, i);
      Break;
    end;
  end;
end;

function InttoStr(Value: Integer): string;
var
  S: string[11];
begin
  Str(Value, S);
  Result := S;
end;

function LowerCase(const S: string): string;
var
  Ch: Char;
  L: Integer;
  Source, Dest: PChar;
begin
  L := Length(S);
  SetLength(Result, L);
  Source := Pointer(S);
  Dest := Pointer(Result);
  while L <> 0 do
  begin
    Ch := Source^;
    if (Ch >= 'A') and (Ch <= 'Z') then Inc(Ch, 32);
    Dest^ := Ch;
    Inc(Source);
    Inc(Dest);
    Dec(L);
  end;
end;

function StrtoInt(const S: string): Integer;
var
  E: Integer;
begin
  Val(S, Result, E);
end;

function ValidFile(var F: file; FileName: string): Boolean;
begin
  AssignFile(F, FileName);
  {$I-}
  Reset(F, 1);
  {$I+}
  Result := IOResult = 0;
end;

function ValidTextFile(var F: TextFile; FileName: string): Boolean;
begin
  AssignFile(F, FileName);
  {$I-}
  Reset(F);
  {$I+}
  Result := IOResult = 0;
end;

function Trim(const S: string): string;
var
  I, L: Integer;
begin
  L := Length(S);
  I := 1;
  while (I <= L) and (S[I] <= ' ') do Inc(I);
  if I > L then Result := '' else
  begin
    while S[L] <= ' ' do Dec(L);
    Result := Copy(S, I, L - I + 1);
  end;
end;

function StrToIntDef(const S: string; Default: Integer): Integer;
var
  E: Integer;
begin
  Val(S, Result, E);
  if E <> 0 then Result := Default;
end;

end.
 